This utility computes the statistics (mean, sd, kurtosis, length) for each state.
It can be based on the local or global decoding result. The concept of asymptotic
statistics can be applied by which the largest N observations (in absolute term)
can be dropped to avoid distortion from outliers.
It is assumed the object already has come with filled data in
observations, states.prob, states.local, states.global slots.
ldhmm.calc_stats_from_obs(object, drop = 0, use.local = TRUE)ldhmm.drop_outliers(x, drop = 1)
an ldhmm object containing results of decoding, based on data
an ldhmm object that contains the observations.
numeric, an integer to drop the largest N observations, default is zero.
logical, use local decoding result, default is TURE.
Otherwise, use global decoding result.
numeric, the observations.
Stephen H. Lihn