This utility estimates historical statistics (mean, volatility and kurtosis) according to the state probabilities.
The ldhmm object must have been decoded by running through ldhmm.decoding function.
Note that kurtosis is naively implemented as the linear sum from each state weighted by state probabilities.
It is subject to change to more rigorous formula in future releases.
ldhmm.decode_stats_history(
object,
ma.order = 0,
annualize = FALSE,
days.pa = 252
)an matrix of statistics history, size of observations times size of 3
a decoded ldhmm object
a positive integer or zero, specifying order of moving average. Default is zero.
logical, to annaulize the sd and mean to V (xsqrt(days.pa)x100) and R (xdays.pa).
Default is FALSE.
a positive integer, specifying number of days per year, default is 252.
Stephen H. Lihn