This utility converts the df input to an xts object with columns and statistics required for the fitting/plot utility in the ecd package. The require columns are Date, Close, logr. This utility can also be used to convert the input from Quandl.
ldhmm.df2ts(
df,
date_format = "%m/%d/%Y",
dt = "Date",
col_in = "Close",
col_out = "Close",
do.logr = TRUE,
rnd.zero = 0.01
)The xts object for the time series
Data.frame of the time serie
Character, date format of the input date column.
It can be NULL to indicate no date conversion is needed.
Default: "%m/%d/%Y".
Character, the name of the input date column. Default: "Date"
Character, the name of the input closing price column. Default: "Close"
Character, the name of the output closing price column. Default: "Close"
logical, if TRUE (default), produce xts object of logr; otherwise, just the col_out column.
numeric, a small random factor (scaled to sd of logr) to avoid an unreal peak of zero log-returns.
if (FALSE) {
ldhmm.df2ts(df)
}
Run the code above in your browser using DataLab