Learn R Programming

ldhmm (version 0.6.1)

ldhmm.forecast_volatility: Computing the volatility forecast for next one period

Description

This utility computes the volatility forecast based on the given future observations for next one period.

Usage

ldhmm.forecast_volatility(object, x, xf, ma.order = 0, days.pa = 252)

Value

matrix of future observations and volatilities, size of 2 times length of xf.

Arguments

object

an ldhmm object

x

numeric, the observations.

xf

numeric, the future observations to be forecasted.

ma.order

a positive integer or zero, specifying order of moving average. Default is zero.

days.pa

a positive integer specifying trading days per year, default is 252.

Author

Stephen H. Lihn