Learn R Programming

ldhmm (version 0.6.1)

ldhmm.log_forward: Computing the log forward and backward probabilities

Description

This utility computes the logarithms of the forward and backward probabilities, aka alpha and beta. The logarithm keeps the computation away from floating point under/over-flow. (Zucchini, 5.4)

Usage

ldhmm.log_forward(object, x)

ldhmm.log_backward(object, x)

Value

numeric, the log probabilities

Arguments

object

an ldhmm object

x

numeric, the observations.

Author

Stephen H. Lihn