This utility computes the MLLK. It is typically invoked by the MLE optimizer. (Zucchini, 3.2)
ldhmm.mllk(object, x, mllk.print.level = 0)an ldhmm object containing results of MLE optimization
an input ldhmm object to provide static reference, such as m, param.nbr, stationary.
numeric, the observations.
numeric, this argument determines the level of printing which is done during the minimization process. The default value of 0 means that no printing occurs, a value of 1 or greater means some tracing information is printed.
Stephen H. Lihn