Learn R Programming

ldhmm (version 0.6.1)

ldhmm.n2w: Transforming natural parameters to a linear working parameter array

Description

This utility linearizes the natural parameters and transforms the contrained parameters to unconstrained parameters. (Zucchini, 3.3.1)

Usage

ldhmm.n2w(object, mu.scale = 1)

Value

numeric, linear working parameter array

Arguments

object

an ldhmm object

mu.scale

numeric, if provided, e.g. mean(abs(x)), it is used to scale up mu so that the scale is more friendly to the optimizer. Default is 1.

Author

Stephen H. Lihn

Examples

Run this code
param0 <- matrix(c(0.003, 0.02, 1, -0.006, 0.03, 1.3), 2, 3, byrow=TRUE)
gamma0 <- matrix(c(0.9, 0.1, 0.1, 0.9), 2, 2, byrow=TRUE)
d <- ldhmm(m=2, param=param0, gamma=gamma0)
v <- ldhmm.n2w(d)

Run the code above in your browser using DataLab