Learn R Programming

ldhmm (version 0.6.1)

ldhmm.read_csv_by_symbol: Read csv file of sample data

Description

This is a helper utility to read sample csv file into data frame. The main use for external users is to read the option data since it has a different format than other price timeseries data.

Usage

ldhmm.read_csv_by_symbol(symbol = "dji", extdata_dir = NULL)

Value

The data.frame object

Arguments

symbol

Character for the symbol of the time series. Default: dji

extdata_dir

optionally specify user's own extdata folder

Author

Stephen H-T. Lihn

Examples

Run this code
dji <- ldhmm.read_csv_by_symbol("dji")
spx <- ldhmm.read_csv_by_symbol("spx")

Run the code above in your browser using DataLab