Learn R Programming

ldhmm (version 0.6.1)

ldhmm.simulate_abs_acf: Simulating auto-correlation (ACF)

Description

This utility simulates the auto-correlation. The first few lag of ACF should match the ACF from the market data fairly well. This is a major validation of a successful HMM. Be aware this is a CPU intensive calculation. It uses the multi-core functionality.

Usage

ldhmm.simulate_abs_acf(object, n = 10000, lag.max = 5, debug = FALSE)

Value

a vector of ACF

Arguments

object

an ldhmm object that can supply m, param.nbr and stationary.

n

a positive integer specifying number of observations to simulate.

lag.max

a positive integer, specifying number of lags to be computed.

debug

logical, specifying to print progress message or not. Default is FALSE.

Author

Stephen H. Lihn