Learn R Programming

ldhmm (version 0.6.1)

ldhmm.ts_abs_acf: Computing ACF of the absolute value of a time series

Description

This utility computes the ACF of the absolute value of a time series as a proxy of the auto-correlation of the volatility. It allows to drop the largest N outliers so that they would not skew the ACF calculation.

Usage

ldhmm.ts_abs_acf(x, drop = 0, lag.max = 100)

Value

a vector of ACF

Arguments

x

numeric, the observations.

drop

a positive integer, specifying number of outliers to be dropped.

lag.max

a positive integer, specifying number of lags to be computed.

Author

Stephen H. Lihn