This utility transforms the working parameter array back to the vectors and matrix of the contrained parameters. (Zucchini, 3.3.1)
ldhmm.w2n(object, par.vector, mu.scale = 1)an ldhmm object
an ldhmm object that can supply m, param.nbr and stationary.
numeric, linear working parameter array. See ldhmm.n2w.
numeric, it should mirror what is provided to ldhmm.n2w.
Default is 1.
Stephen H. Lihn