This utility computes the volatility forecast based on the given future observations for next one period.
ldhmm.forecast_volatility(object, x, xf, ma.order = 0, days.pa = 252)matrix of future observations and volatilities, size of 2 times length of xf.
an ldhmm object
numeric, the observations.
numeric, the future observations to be forecasted.
a positive integer or zero, specifying order of moving average. Default is zero.
a positive integer specifying trading days per year, default is 252.
Stephen H. Lihn