This utility simulates the auto-correlation. The first few lag of ACF should match the ACF from the market data fairly well. This is a major validation of a successful HMM. Be aware this is a CPU intensive calculation. It uses the multi-core functionality.
ldhmm.simulate_abs_acf(object, n = 10000, lag.max = 5, debug = FALSE)a vector of ACF
an ldhmm object that can supply m, param.nbr and stationary.
a positive integer specifying number of observations to simulate.
a positive integer, specifying number of lags to be computed.
logical, specifying to print progress message or not. Default is FALSE.
Stephen H. Lihn