ldhmm.state_ld: Constructing the ecld objects per state
Description
This utility constructs the ecld objects per state and return them in a list of easy query.
Usage
ldhmm.state_ld(object, state = NULL)
Value
a list of ecld objects
Arguments
- object
an ldhmm object
- state
numeric, the states.