This utility computes the ACF of the absolute value of a time series as a proxy of the auto-correlation of the volatility. It allows to drop the largest N outliers so that they would not skew the ACF calculation.
ldhmm.ts_abs_acf(x, drop = 0, lag.max = 100)a vector of ACF
numeric, the observations.
a positive integer, specifying number of outliers to be dropped.
a positive integer, specifying number of lags to be computed.
Stephen H. Lihn